<?php

declare(strict_types=1);

namespace Dedi\SyliusAdvertisingPlugin\Entity;

use Doctrine\ORM\Mapping as ORM;
use Sylius\Component\Resource\Model\AbstractTranslation;
use Sylius\Component\Resource\Model\ResourceInterface;
use Symfony\Component\Validator\Constraints as Assert;

/**
 * @ORM\Entity()
 * @ORM\Table(name="dedi_advertising_translation")
 */
class AdvertisingTranslation extends AbstractTranslation implements ResourceInterface
{
    /**
     * @ORM\Id()
     * @ORM\GeneratedValue(strategy="AUTO")
     * @ORM\Column(type="integer", nullable=false, name="id")
     */
    protected ?int $id = null;

    /**
     * @ORM\Column(type="string", nullable=true, name="translation_url")
     * @Assert\Length(max="255", groups={"default", "sylius"})
     * @Assert\Url()
     */
    protected ?string $url = null;

    /**
     * @ORM\Column(type="string", nullable=true, name="translation_title")
     * @Assert\Length(max="255", groups={"default", "sylius"})
     */
    protected ?string $title = null;

    /**
     * @ORM\Column(type="text", nullable=true, name="translation_content")
     */
    protected ?string $content = null;

    public function getId()
    {
        return $this->id;
    }

    public function getUrl(): ?string
    {
        return $this->url;
    }

    public function setUrl(?string $url): self
    {
        $this->url = $url;

        return $this;
    }

    public function getContent(): ?string
    {
        return $this->content;
    }

    public function setContent(?string $content): self
    {
        $this->content = $content;

        return $this;
    }

    public function getTitle(): ?string
    {
        return $this->title;
    }

    public function setTitle(?string $title): self
    {
        $this->title = $title;

        return $this;
    }
}
