<?php

declare(strict_types=1);

namespace Dedi\SyliusAdvertisingPlugin\Form;

use Dedi\SyliusAdvertisingPlugin\Entity\Advertising;
use Sylius\Bundle\ResourceBundle\Form\Type\ResourceTranslationsType;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\Extension\Core\Type\CheckboxType;
use Symfony\Component\Form\Extension\Core\Type\NumberType;
use Symfony\Component\Form\Extension\Core\Type\TextType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;
use Symfony\Component\Validator\Constraints\Valid;

class AdvertisingType extends AbstractType
{
    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $builder
            ->add('enabled', CheckboxType::class, [
                'label' => 'dedi_advertising.form.advertising.enabled'
            ])
            ->add('position', NumberType::class, [
                'html5' => true,
                'label' => 'dedi_advertising.form.advertising.position',
            ])
            ->add('code', TextType::class, [
                'label' => 'dedi_advertising.form.advertising.code',
            ])
            ->add('translations', ResourceTranslationsType::class, [
                'entry_type' => AdvertisingTranslationType::class,
                'constraints' => [new Valid()]
            ])
            ->add('image', AdvertisingImageType::class, [
                'required' => false,
                'label' => 'dedi_advertising.form.advertising.image',
            ])
        ;
    }

    public function configureOptions(OptionsResolver $resolver)
    {
        $resolver->setDefaults([
            'data_class' => Advertising::class,
            'validation_groups' => ['default', 'sylius'],
        ]);
    }
}
