<?php

declare(strict_types=1);

namespace Dedi\SyliusAdvertisingPlugin\Repository;

use Doctrine\ORM\QueryBuilder;
use Sylius\Bundle\ResourceBundle\Doctrine\ORM\EntityRepository;
use Sylius\Component\Core\Model\ChannelInterface;

class AdvertisingZoneRepository extends EntityRepository implements AdvertisingZoneRepositoryInterface
{
    protected function createBaseQueryBuilder(ChannelInterface $channel, ?string $locale = null): QueryBuilder
    {
        $queryBuilder = $this->createQueryBuilder('o')
            ->innerJoin('o.advertising', 'a')
            ->innerJoin('a.translations', 'translation', 'WITH', 'translation.locale = :locale')
            ->andWhere(':channel MEMBER OF o.channels')
            ->andWhere('o.enabled = true')
            ->andWhere('a.enabled = true')
            ->orderBy('a.position', 'ASC')
            ->setParameter('channel', $channel)
        ;

        if (null !== $locale) {
            $queryBuilder
                ->andWhere('translation.locale = :locale')
                ->setParameter('locale', $locale)
            ;
        }

        return $queryBuilder;
    }

    public function findOneByChannelAndCode(ChannelInterface $channel, string $code, ?string $locale = null)
    {
        return $this->createBaseQueryBuilder($channel, $locale)
            ->andWhere('o.code = :code')
            ->setParameter('code', $code)
            ->getQuery()
            ->getOneOrNullResult()
        ;
    }
}
